# The CW Equation Generator

The cweqgen package (pronouced like "_Queck-Jen_") provides a way to generate a range
of common CW equations using user supplied fiducial values.

* [Documentation](https://cweqgen.readthedocs.io)

[![Documentation Status](https://readthedocs.org/projects/cweqgen/badge/?version=latest)](https://cweqgen.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/cweqgen.svg)](https://badge.fury.io/py/cweqgen)
